@@ -29,7 +29,7 @@ from pyDE1.dispatcher.resource import (
     Resource, RESOURCE_VERSION, DE1ModeEnum, ConnectivityEnum
 )
 
-MAPPING_VERSION = "4.1.1"
+MAPPING_VERSION = "5.0.0"
 
 logger = pyDE1.getLogger('Inbound.Mapping')
 
@@ -209,10 +209,9 @@ MAPPING[Resource.DE1_FIRMWARE_CANCEL] = IsAt(target=TO.DE1, attr_path=None,
 
 MAPPING[Resource.SCAN] = {
     # Passing a number sets the timeout. Passing null takes the default.
-    # Use of bool DEPRECATED -- 2022-02-05
     'begin': IsAt(target=None, attr_path=None,
                   setter_path='scan_from_api',
-                  v_type=Optional[Union[int, float, bool]])
+                  v_type=Optional[Union[int, float]])
 }
 
 # Note: This is an async getter because of the lock
@@ -233,10 +232,6 @@ MAPPING[Resource.DE1_ID] = {
     'id': IsAt(target=TO.DE1, attr_path='address', v_type=Optional[str],
                setter_path='change_de1_to_id',
                if_not_ready=True),
-    # DEPRECATED -- 2022-02-05
-    'first_if_found': IsAt(target=TO.DE1, attr_path=None,
-                           setter_path='first_if_found', v_type=bool,
-                           if_not_ready=True),
 }
 
 # NB: A single-entry tuple needs to end with a comma
@@ -294,6 +289,9 @@ MAPPING[Resource.DE1_CONTROL_ESPRESSO] = {
     'stop_at_weight': IsAt(target=TO.FlowSequencer,
                            attr_path='espresso_control.stop_at_weight',
                            v_type=Optional[float]),
+    'move_on_weight': IsAt(target=TO.FlowSequencer,
+                           attr_path='espresso_control.mow_all_frames',
+                           v_type=list[Optional[Union[int, float]]]),
     'disable_auto_tare': IsAt(target=TO.FlowSequencer,
                               attr_path='espresso_control.disable_auto_tare',
                               v_type=bool),
@@ -399,6 +397,7 @@ MAPPING[Resource.DE1_SETTING_STEAM] = {
     'temperature': IsAt(target=ShotSettings, attr_path='TargetSteamTemp', v_type=int),
     'flow': IsAt(target=MMR0x80LowAddr.TARGET_STEAM_FLOW, attr_path='', v_type=float),
     'high_flow_time': IsAt(target=MMR0x80LowAddr.STEAM_START_SECS, attr_path='', v_type=float),
+    'purge_deferred': IsAt(target=MMR0x80LowAddr.STEAM_PURGE_MODE, attr_path='', v_type=bool),
 }
 
 # TODO: What is ShotSettings.TargetGroupTemp in the current DE1 firmware
@@ -407,6 +406,16 @@ MAPPING[Resource.DE1_SETTING_TARGET_GROUP_TEMP] = {
     'temperature': IsAt(target=ShotSettings, attr_path='TargetGroupTemp', v_type=int),
 }
 
+MAPPING[Resource.DE1_SETTING_USB_OUTLET] = {
+    'enabled':  IsAt(target=MMR0x80LowAddr.ALLOW_USB_CHARGING,
+                     attr_path='', v_type=bool),
+}
+
+MAPPING[Resource.DE1_SETTING_REFILL_KIT] = {
+    'present':  IsAt(target=MMR0x80LowAddr.REFILL_KIT_PRESENT,
+                     attr_path='', v_type=bool),
+}
+
 # NB: Not exposed at this time
 MAPPING[Resource.DE1_DEPRECATED] = {
     'old_espresso_vol': IsAt(target=ShotSettings,
@@ -461,6 +470,11 @@ MAPPING[Resource.DE1_CALIBRATION_LINE_FREQUENCY] = {
     'hz': IsAt(target=TO.DE1, attr_path='line_frequency', v_type=int)
 }
 
+MAPPING[Resource.DE1_PRESENCE] = {
+    'user': IsAt(target=MMR0x80LowAddr.USER_PRESENT, attr_path='', v_type=bool)
+
+}
+
 MAPPING[Resource.SCALE_ID] = {
     'name': IsAt(target=TO.ScaleProcessor, attr_path='scale_name',
                  v_type=Optional[str],
@@ -475,10 +489,6 @@ MAPPING[Resource.SCALE_ID] = {
                  v_type=Optional[str],
                  read_only=True,
                  if_not_ready=True),
-    # DEPRECATED -- 2022-02-05
-    'first_if_found': IsAt(target=TO.ScaleProcessor, attr_path=None,
-                           setter_path='first_if_found', v_type=bool,
-                           if_not_ready=True),
 }
 
 MAPPING[Resource.SCALE_CONNECTIVITY] = {
@@ -514,6 +524,8 @@ MAPPING[Resource.DE1_SETTING] = {
     'target_group_temp': MAPPING[Resource.DE1_SETTING_TARGET_GROUP_TEMP],
     'steam': MAPPING[Resource.DE1_SETTING_STEAM],
     'time': MAPPING[Resource.DE1_SETTING_TIME],
+    'usb_outlet': MAPPING[Resource.DE1_SETTING_USB_OUTLET],
+    'refill_kit': MAPPING[Resource.DE1_SETTING_REFILL_KIT],
 }
 
 MAPPING[Resource.DE1_CALIBRATION] = {
